==> xl-react-components-0.16.62.tgz: package/app/xl-react-widget/xl-react-widget-file-upload/xl-react-widget-file-upload-component.js <==
import React, {PureComponent} from 'react';
import PropTypes from 'prop-types';
import R from 'ramda';
import RS from 'ramdasauce';
import template from 'lodash.template';
import FileUpload from 'xl-react-fileupload';
import classNames from 'classnames';
import {xlMessageTypeProp} from '../../xl-props/xl-message-type-prop';
import {ERROR} from '../../utils/ci-utils';
import {validationMessageClasses} from '../../utils/css-utils';
import {XlReactWidgetProgressbar} from '../xl-react-widget-progressbar/xl-react-widget-progressbar';
import {localeMessages} from '../../services/locale-service';
import {XlReactFormItemControl} from '../../xl-react-form/xl-react-form-item-control';

import './xl-react-widget-file-upload.less';

export class XlReactWidgetFileUploadComponent extends PureComponent {
    static propTypes = {
        autoUpload: PropTypes.bool,
        browseButtonType: PropTypes.oneOf(['primary', 'secondary']),
        currentProgress: PropTypes.number,
        currentStatus: PropTypes.oneOf(['pristine', 'error', 'progress', 'success']),
        description: PropTypes.string,
        disabled: PropTypes.bool,
        fileNameField: PropTypes.string,
        handleOnChange: PropTypes.func,
        handleUploadError: PropTypes.func,
        handleUploadingProgress: PropTypes.func,
        handleUploadSuccess: PropTypes.func,
        label: PropTypes.string,
        message: xlMessageTypeProp,
        model: PropTypes.object,
        onValidityChange: PropTypes.func,
        pristine: PropTypes.bool,
        requestHeaders: PropTypes.array,
        required: PropTypes.bool,
        uploadUrl: PropTypes.string,
        valid: PropTypes.bool
    };

    static defaultProps = {browseButtonType: 'primary', currentProgress: 0, currentStatus: 'pristine'};

    storeFileUploaderRef = (ref) => {
        this.fileUploader = ref;
    };

    render() {
        const {
            browseButtonType, currentProgress, currentStatus, disabled, message, model, valid
        } = this.props;

        const fileUploadOptions = {
            baseUrl: R.pathOr('/', ['uploadUrl'], this.props),
            chooseAndUpload: R.pathOr(false, ['autoUpload'], this.props),
            chooseFile: (files) => {
                this.props.handleOnChange(R.head(files));
            },
            fileFieldName: R.pathOr('fileName', ['fileNameField'], this.props),
            requestHeaders: this.props.requestHeaders,
            uploadError: (resp) => {
                this.props.handleUploadError({message: {show: false, text: resp, type: ERROR}, state: 'error'});
            },
            uploading: (progress) => {
                const loaded = progress.loaded;
                const total = progress.total;
                this.props.handleUploadingProgress({
                    currentProgress: Math.round(100 * loaded / total),
                    state: 'progress'
                });
            },
            uploadSuccess: (resp) => {
                this.props.handleUploadSuccess({message: {show: false, text: resp, type: ERROR}, state: 'success'});
            }
        };

        const onCloseButtonClick = () => {
            this.fileUploader.ajaxUploadFileInput.value = '';
            this.props.handleOnChange();
        };

        const closeBtn = () => !disabled && !RS.isNilOrEmpty(model) ?
            <span className="xl-react-btn-close" onClick={onCloseButtonClick}/> : null;

        const browseButtonClasses = classNames(
            'xl-react-button',
            `xl-${browseButtonType}`,
            'file-selector-button'
        );

        const browseButton = () => <button
            className={browseButtonClasses}
            disabled={disabled}
            ref={this.props.autoUpload ? 'chooseAndUpload' : 'chooseBtn'}
            type="button">
            {localeMessages.browseButton}
        </button>;

        const progressBarArea = () => {
            const progressbar = () => <XlReactWidgetProgressbar
                currentStatus={currentStatus}
                disabled={disabled}
                model={currentProgress}
                stripped={true}
            />;

            return currentStatus !== 'pristine' ?
                <div className="file-upload-area">
                    {progressbar()}
                    <div className="upload-progress-message">
                        {template(localeMessages.uploadedMessage)({currentProgress})}
                    </div>
                </div> : null;
        };

        const fileName = R.pathOr('', ['model', 'name'], this.props);

        const fileNameClassName = classNames(
            'file-name',
            validationMessageClasses(valid, message)
        );

        return <XlReactFormItemControl {...({...this.props, controlClass: 'xl-react-widget-file-upload'})}>
            <div className="file-upload-browse-area">
                <input
                    className={fileNameClassName}
                    disabled={true}
                    required={this.props.required}
                    type="text"
                    value={fileName}
                />
                <div className="actual-file-upload">
                    <FileUpload
                        options={fileUploadOptions}
                        ref={this.storeFileUploaderRef}>
                        {browseButton()}
                    </FileUpload>
                </div>
                {closeBtn()}
            </div>
            {progressBarArea()}
        </XlReactFormItemControl>;
    }
}

==> xl-react-components-0.21.12.tgz: package/app/xl-react-widget/xl-react-widget-file-upload/xl-react-widget-file-upload-component.js <==
import React, {PureComponent} from 'react';
import PropTypes from 'prop-types';
import R from 'ramda';
import RS from 'ramdasauce';
import template from 'lodash.template';
import FileUpload from 'xl-react-fileupload';
import classNames from 'classnames';
import {xlMessageTypeProp} from '../../xl-props/xl-message-type-prop';
import {ERROR} from '../../utils/ci-utils';
import {validationMessageClasses} from '../../utils/css-utils';
import {XlReactWidgetProgressbar} from '../xl-react-widget-progressbar/xl-react-widget-progressbar';
import {localeMessages} from '../../services/locale-service';
import {XlReactFormItemControl} from '../../xl-react-form/xl-react-form-item-control';

import './xl-react-widget-file-upload.less';

export class XlReactWidgetFileUploadComponent extends PureComponent {
    static propTypes = {
        autoUpload: PropTypes.bool,
        browseButtonType: PropTypes.oneOf(['primary', 'secondary']),
        currentProgress: PropTypes.number,
        currentStatus: PropTypes.oneOf(['pristine', 'error', 'progress', 'success']),
        description: PropTypes.string,
        disabled: PropTypes.bool,
        fileNameField: PropTypes.string,
        handleOnChange: PropTypes.func,
        handleUploadError: PropTypes.func,
        handleUploadingProgress: PropTypes.func,
        handleUploadSuccess: PropTypes.func,
        label: PropTypes.string,
        message: xlMessageTypeProp,
        model: PropTypes.object,
        onValidityChange: PropTypes.func,
        pristine: PropTypes.bool,
        requestHeaders: PropTypes.array,
        required: PropTypes.bool,
        uploadUrl: PropTypes.string,
        valid: PropTypes.bool
    };

    static defaultProps = {browseButtonType: 'primary', currentProgress: 0, currentStatus: 'pristine'};

    storeFileUploaderRef = (ref) => {
        this.fileUploader = ref;
    };

    render() {
        const {
            browseButtonType, currentProgress, currentStatus, disabled, message, model, valid
        } = this.props;

        const fileUploadOptions = {
            baseUrl: R.pathOr('/', ['uploadUrl'], this.props),
            chooseAndUpload: R.pathOr(false, ['autoUpload'], this.props),
            chooseFile: (files) => {
                this.props.handleOnChange(R.head(files));
            },
            fileFieldName: R.pathOr('fileName', ['fileNameField'], this.props),
            requestHeaders: this.props.requestHeaders,
            uploadError: (resp) => {
                this.props.handleUploadError({message: {show: false, text: resp, type: ERROR}, state: 'error'});
            },
            uploading: (progress) => {
                const loaded = progress.loaded;
                const total = progress.total;
                this.props.handleUploadingProgress({
                    currentProgress: Math.round(100 * loaded / total),
                    state: 'progress'
                });
            },
            uploadSuccess: (resp) => {
                this.props.handleUploadSuccess({message: {show: false, text: resp, type: ERROR}, state: 'success'});
            }
        };

        const onCloseButtonClick = () => {
            this.fileUploader.ajaxUploadFileInput.value = '';
            this.props.handleOnChange();
        };

        const closeBtn = () => !disabled && !RS.isNilOrEmpty(model) ?
            <i className="xl-icon close-icon" onClick={onCloseButtonClick}/> : null;

        const browseButtonClasses = classNames(
            'xl-react-button',
            `xl-${browseButtonType}`,
            'file-selector-button'
        );

        const browseButton = () => <button
            className={browseButtonClasses}
            disabled={disabled}
            ref={this.props.autoUpload ? 'chooseAndUpload' : 'chooseBtn'}
            type="button">
            {localeMessages.browseButton}
        </button>;

        const progressBarArea = () => {
            const progressbar = () => <XlReactWidgetProgressbar
                currentStatus={currentStatus}
                disabled={disabled}
                model={currentProgress}
                stripped={true}
            />;

            return currentStatus !== 'pristine' ?
                <div className="file-upload-area">
                    {progressbar()}
                    <div className="upload-progress-message">
                        {template(localeMessages.uploadedMessage)({currentProgress})}
                    </div>
                </div> : null;
        };

        const fileName = R.pathOr('', ['model', 'name'], this.props);

        const fileNameClassName = classNames(
            'file-name',
            validationMessageClasses(valid, message)
        );

        return <XlReactFormItemControl {...({...this.props, controlClass: 'xl-react-widget-file-upload'})}>
            <div className="file-upload-browse-area">
                <input
                    className={fileNameClassName}
                    disabled={true}
                    required={this.props.required}
                    type="text"
                    value={fileName}
                />
                <div className="actual-file-upload">
                    <FileUpload
                        options={fileUploadOptions}
                        ref={this.storeFileUploaderRef}>
                        {browseButton()}
                    </FileUpload>
                </div>
                {closeBtn()}
            </div>
            {progressBarArea()}
        </XlReactFormItemControl>;
    }
}
